Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(574)

Unified Diff: third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h

Issue 1856933002: WebGL GL_RGB emulation to support IOSurfaces on Mac. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Full client side implementation of GL_RGB emulation. Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
diff --git a/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h b/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
index a477c75a46dc1cb42f20534e4f2fbb786f326b60..c964acccf7979068a07e47ef14716604c0eb2f22 100644
--- a/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
+++ b/third_party/WebKit/Source/modules/webgl/WebGLRenderingContextBase.h
@@ -753,7 +753,8 @@ protected:
// Errors raised by synthesizeGLError() while the context is lost.
Vector<GLenum> m_lostContextErrors;
// Other errors raised by synthesizeGLError().
Vector<GLenum> m_syntheticErrors;
bool m_isWebGL2FormatsTypesAdded;
@@ -795,6 +796,10 @@ protected:
// Helper to restore state that clearing the framebuffer may destroy.
void restoreStateAfterClear();
+ // Moves all errors from the service side's error queue into this class's
+ // internal queue |m_syntheticErrors|.
+ void moveGLErrorsToInternalQueue();
+
// Convert texture internal format.
GLenum convertTexInternalFormat(GLenum internalformat, GLenum type);
@@ -753,7 +753,8 @@ protected:
// Errors raised by synthesizeGLError() while the context is lost.
Vector<GLenum> m_lostContextErrors;
- // Other errors raised by synthesizeGLError().
+ // Other errors raised by synthesizeGLError(), or errors transfered from the
+ // service side's error queue.
Vector<GLenum> m_syntheticErrors;
bool m_isWebGL2FormatsTypesAdded;

Powered by Google App Engine
This is Rietveld 408576698